# OneTool Guides

Practical guides for building and configuring OneTool-specific features.

---

## Creating Tools

How to build tool packs for OneTool.

| Guide | Topic |
|-------|-------|
| [Creating Tools](creating-tools.md) | Complete guide to building tool packs |
| [Tool Configuration](tool-configuration.md) | Adding tool-specific configuration |
| [Attribution](attribution.md) | License handling for derived tools |

---

## Configuration

OneTool configuration system.

| Guide | Topic |
|-------|-------|
| [Configuration](configuration.md) | OneTool configuration system overview |
| [Tool Configuration](tool-configuration.md) | Tool-specific config patterns |

---

## Quick Reference

| I want to... | See |
|--------------|-----|
| Create a new tool pack | [Creating Tools](creating-tools.md) |
| Add configuration to my tool | [Tool Configuration](tool-configuration.md) |
| Handle third-party code licenses | [Attribution](attribution.md) |
| Configure OneTool | [Configuration](configuration.md) |

---

**Related:**
- [Architecture](../arch/index.md) - OneTool architecture and design
- [Testing](../../practices/testing.md) - Testing your tools
- [Logging](../../practices/logging.md) - LogSpan patterns for tools
